@@ -4,7 +4,7 @@ Tests for the django-reversion API.
 These tests require Python 2.5 to run.
 """
 
-from __future__ import with_statement
+from __future__ import unicode_literals
 
 import datetime, os
 
@@ -12,12 +12,13 @@ from django.db import models
 from django.test import TestCase
 from django.core.management import call_command
 from django.conf import settings
-from django.conf.urls.defaults import *
+from django.conf.urls import url, patterns, include
 from django.contrib import admin
 from django.contrib.auth.models import User
 from django.utils.decorators import decorator_from_middleware
 from django.http import HttpResponse
 from django.utils.unittest import skipUnless
+from django.utils.encoding import force_text, python_2_unicode_compatible
 
 import reversion
 from reversion.revisions import RegistrationError, RevisionManager
@@ -40,13 +41,14 @@ class UTC(datetime.tzinfo):
     def dst(self, dt):
         return ZERO
 
+@python_2_unicode_compatible
 class ReversionTestModelBase(models.Model):
 
     name = models.CharField(
         max_length = 100,
     )
     
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     class Meta:
@@ -64,7 +66,7 @@ str_pk_gen = 0;
 def get_str_pk():
     global str_pk_gen
     str_pk_gen += 1;
-    return str(str_pk_gen)
+    return force_text(str_pk_gen)
     
     
 class ReversionTestModel2(ReversionTestModelBase):
@@ -156,6 +158,9 @@ class ReversionTestBase(TestCase):
         del self.user
         # Delete the revisions index.
         Revision.objects.all().delete()
+        # Unregister all remaining models.
+        for registered_model in reversion.get_registered_models():
+            reversion.unregister(registered_model)
         # Re-register initial registered models.
         for initial_model, adapter in self.initial_registered_models:
             reversion.register(initial_model, adapter_cls=adapter)
@@ -431,8 +436,6 @@ class MultiTableInheritanceApiTest(RevisionTestBase):
     
     def tearDown(self):
         super(MultiTableInheritanceApiTest, self).tearDown()
-        reversion.unregister(ReversionTestModel1Child)
-        ReversionTestModel1Child.objects.all().delete()
         del self.testchild1
 
 
@@ -645,13 +648,14 @@ class ParentTestAdminModel(models.Model):
         app_label = "auth"  # Hack: Cannot use an app_label that is under South control, due to http://south.aeracode.org/ticket/520
 
 
+@python_2_unicode_compatible
 class ChildTestAdminModel(ParentTestAdminModel):
 
     child_name = models.CharField(
         max_length = 200,
     )
     
-    def __unicode__(self):
+    def __str__(self):
         return self.child_name
     
     class Meta:
@@ -831,14 +835,4 @@ class PatchTest(RevisionTestBase):
     def tearDown(self):
         super(PatchTest, self).tearDown()
         del self.version1
-        del self.version2
-
-
-# Import the deprecated tests.
-from reversion import tests_deprecated
-
-for name, value in vars(tests_deprecated).iteritems():
-    if isinstance(value, type) and issubclass(value, TestCase):
-        globals()[name] = value
-del name
-del value
+        del self.version2
\ No newline at end of file
